# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-13 09:20
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('blogging', '0004_auto_20150504_1826'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='category',
            options={'ordering': ['name'], 'verbose_name': 'category', 'verbose_name_plural': 'categories'},
        ),
        migrations.AlterModelOptions(
            name='post',
            options={'ordering': ['-published_on'], 'verbose_name': 'item', 'verbose_name_plural': 'items'},
        ),
        migrations.AddField(
            model_name='post',
            name='post_type',
            field=models.IntegerField(choices=[(1, 'Text'), (2, 'Quote'), (3, 'Link'), (4, 'Video')], db_index=True, default=1, verbose_name='Type'),
        ),
        migrations.AddField(
            model_name='post',
            name='source',
            field=models.URLField(blank=True, null=True, verbose_name='Post source'),
        ),
        migrations.AlterField(
            model_name='category',
            name='name',
            field=models.CharField(max_length=100, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='picture',
            name='name',
            field=models.CharField(max_length=100, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='post',
            name='author',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Author'),
        ),
        migrations.AlterField(
            model_name='post',
            name='categories',
            field=models.ManyToManyField(to='blogging.Category', verbose_name='Categories'),
        ),
        migrations.AlterField(
            model_name='post',
            name='comments_open',
            field=models.BooleanField(default=True, verbose_name='Are comments open?'),
        ),
        migrations.AlterField(
            model_name='post',
            name='content',
            field=models.TextField(verbose_name='Content'),
        ),
        migrations.AlterField(
            model_name='post',
            name='published_on',
            field=models.DateTimeField(db_index=True, verbose_name='Published on'),
        ),
        migrations.AlterField(
            model_name='post',
            name='selected',
            field=models.BooleanField(default=False, verbose_name='Selected'),
        ),
        migrations.AlterField(
            model_name='post',
            name='slug',
            field=models.SlugField(max_length=150, verbose_name='Slug'),
        ),
        migrations.AlterField(
            model_name='post',
            name='status',
            field=models.IntegerField(choices=[(1, 'Draft'), (2, 'Published'), (3, 'Deleted')], db_index=True, default=1, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='post',
            name='title',
            field=models.CharField(max_length=150, verbose_name='Title'),
        ),
        migrations.AlterUniqueTogether(
            name='post',
            unique_together=set([('site', 'slug')]),
        ),
    ]
